<?php $TRANSLATIONS = array(
"Pictures" => "相片",
"Share" => "分享",
"The \"Image Viewer\" application also need to be enabled to use this application." => "使用此应用需同时启用\"相片查看器\"应用。"
);
